@@ -1,8 +1,8 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 from django.contrib import messages
+from functools import wraps
 from . import utils
-from .models import PhitbitUser
 
 
 def phitbit_authenticated(msg=utils.defaults['PHITBIT_AUTH_MESSAGE']):
@@ -15,7 +15,7 @@ def phitbit_authenticated(msg=utils.defaults['PHITBIT_AUTH_MESSAGE']):
     def inner_decorator(view_func):
         def wrapped(request, *args, **kwargs):
             user = request.user
-            if not utils.phitbit._authenticated():
+            if not user.phitbit._authenticated():
                 text = msg(request) if callable(msg) else msg
                 messages.error(request, text)
             return view_func(request, *args, **kwargs)
