@@ -19,6 +19,6 @@ def get_setting(s):
     if hasattr(settings, s):
         return getattr(settings, s)
     else:
-        return defaults(s)
+        return defaults[s]
     msg = '%s must be set in settings', s
     raise ImproperlyConfigured(msg)
